@@ -42,11 +42,10 @@
 #include <string.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include "tools.h"
 
+#include "tools.h"
+#include "record.h"
 #include "udem.h"
-#include "node.h"
-#include "binblock.h"
 
 typedef struct {
   float timestart;
@@ -1117,8 +1116,6 @@ void free_demfile(DEMFILE_t *demfile)
 
 void open_output(STATE_t *state)
 {
-  unsigned int  *a;
-  a=NULL;
   if (state->output_dem == NULL) {
     if ((state->output_dem = (DEM_t*)malloc(sizeof(DEM_t)))==NULL)
       syserror(ENOMEM,"output_dem malloc");
